@@ -1,6 +1,7 @@
 pub mod backend;
 pub mod cargolifter;
 pub mod filesystem;
+pub mod gitea;
 pub mod github;
 pub mod gitlab;
 pub mod s3;
@@ -10,6 +11,7 @@ pub mod web;
 pub use backend::*;
 pub use cargolifter::*;
 pub use filesystem::*;
+pub use gitea::*;
 pub use github::*;
 pub use gitlab::*;
 pub use s3::*;
